@@ -14,27 +14,28 @@ use crate::settings::AppSettings;
 use crate::view::ImageViewer;
 use crate::window::Capture;
 use bytesize::ByteSize;
-use image::bmp::BmpEncoder;
+use image::codecs::bmp::BmpEncoder;
+use image::codecs::farbfeld::FarbfeldEncoder;
+use image::codecs::gif::GifDecoder;
+use image::codecs::ico::IcoEncoder;
+use image::codecs::jpeg::JpegEncoder;
+use image::codecs::openexr::OpenExrEncoder;
 use image::codecs::png::PngDecoder;
+use image::codecs::png::PngEncoder;
+use image::codecs::pnm::{PnmEncoder, PnmSubtype};
+use image::codecs::tga::TgaEncoder;
+use image::codecs::tiff::TiffEncoder;
+use image::codecs::webp::WebPEncoder;
 use image::error::{
 	ImageError, ImageFormatHint, UnsupportedError, UnsupportedErrorKind,
 };
-use image::farbfeld::FarbfeldEncoder;
-use image::gif::GifDecoder;
-use image::ico::IcoEncoder;
 use image::io::Reader;
-use image::jpeg::JpegEncoder;
-use image::png::PngEncoder;
-use image::pnm::{PnmEncoder, PnmSubtype};
-use image::tga::TgaEncoder;
-use image::tiff::TiffEncoder;
 use image::{
 	AnimationDecoder, ColorType, ExtendedColorType, ImageEncoder, ImageFormat,
 };
-use std::convert::TryInto;
 use std::fmt::Debug;
 use std::fs::{self, File};
-use std::io::{self, Read, Write};
+use std::io::{self, Cursor, Read, Seek, Write};
 use std::path::Path;
 use std::thread;
 use thiserror::Error as ThisError;
@@ -119,7 +120,9 @@ where
 			debug!("Viewing the image... ({:?})", self.settings.view.file);
 			self.view_image()?;
 		} else if self.settings.save.file.path.to_str() == Some("-") {
-			self.save_output(self.get_app_output()?, io::stdout())?;
+			let mut buffer = Cursor::new(Vec::new());
+			self.save_output(self.get_app_output()?, &mut buffer)?;
+			io::stdout().write_all(&buffer.into_inner())?;
 		} else {
 			self.save_output(
 				self.get_app_output()?,
@@ -368,7 +371,7 @@ where
 		fs::create_dir_all(&self.settings.split.dir)?;
 		for i in 0..frames.len() {
 			let path = FileUtil::get_path_with_extension(
-				self.settings.split.dir.join(format!("frame_{}", i,)),
+				self.settings.split.dir.join(format!("frame_{i}",)),
 				&self.settings.save.file.format,
 			);
 			debug!("Saving to {:?}\r", path);
@@ -386,7 +389,7 @@ where
 	 * @param   output
 	 * @return  Result
 	 */
-	fn save_output<Output: Write>(
+	fn save_output<Output: Write + Seek>(
 		&self,
 		app_output: AppOutput,
 		mut output: Output,
@@ -418,6 +421,14 @@ where
 				),
 				ExtendedColorType::Rgb8,
 			),
+			FileFormat::WebP => self.save_image(
+				image,
+				WebPEncoder::new_with_quality(
+					&mut output,
+					self.settings.webp.get_quality(),
+				),
+				ExtendedColorType::Rgb8,
+			),
 			FileFormat::Bmp => self.save_image(
 				image,
 				BmpEncoder::new(&mut output),
@@ -453,6 +464,11 @@ where
 				FarbfeldEncoder::new(output),
 				ExtendedColorType::Rgba16,
 			),
+			FileFormat::Exr => self.save_image(
+				image,
+				OpenExrEncoder::new(output),
+				ExtendedColorType::Rgba32F,
+			),
 			_ => Ok(()),
 		}
 	}
@@ -493,6 +509,7 @@ where
 				ExtendedColorType::L1 | ExtendedColorType::L8 => ColorType::L8,
 				ExtendedColorType::Rgb8 => ColorType::Rgb8,
 				ExtendedColorType::Rgba16 => ColorType::Rgba16,
+				ExtendedColorType::Rgba32F => ColorType::Rgba32F,
 				_ => ColorType::Rgba8,
 			},
 		)?;
@@ -619,6 +636,7 @@ mod tests {
 			FileFormat::Tga,
 			FileFormat::Pnm(String::from("ppm")),
 			FileFormat::Ff,
+			FileFormat::Exr,
 		] {
 			let path =
 				FileUtil::get_path_with_extension(PathBuf::from("test.*"), &format);
@@ -659,7 +677,7 @@ mod tests {
 		app.save_apng(Some((images.clone(), 20)), File::create("test.apng")?)?;
 		fs::remove_file("test.apng")?;
 		for i in 0..images.len() {
-			let path = PathBuf::from(format!("frame_{}.png", i));
+			let path = PathBuf::from(format!("frame_{i}.png"));
 			if path.exists() {
 				fs::remove_file(path)?;
 			}
